/** \file
 *  \brief Declares the CombinedEventWriter class
 *
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */

#pragma once

#include <memory>
#include <vector>

#include "HEJ/EventWriter.hh"
#include "HEJ/output_formats.hh"

namespace LHEF{
  struct HEPRUP;
}

namespace HEJ{

  //! Write event output to zero or more output files.
  class CombinedEventWriter: public EventWriter{
  public:
    //!Constructor
    /**
     * @param outfiles     Specifies files output should be written to.
     *                     Each entry in the vector contains a file name
     *                     and output format.
     * @param heprup       General process information
     */
    CombinedEventWriter(
        std::vector<OutputFile> const & outfiles,
        LHEF::HEPRUP const & heprup
    );

    //! Write one event to all output files
    void write(Event const &) override;

  private:
    std::vector<std::unique_ptr<EventWriter>> writers_;
  };

}
