/** \file
 *  \brief Header file defining all global constants used for HEJ
 *
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */
#pragma once

namespace HEJ{
/// @name QCD parameters
//@{
  constexpr double N_C = 3.;    //!< number of Colours
  constexpr double C_A = N_C;    //!< \f$C_A\f$
  constexpr double C_F = (N_C*N_C - 1.)/(2.*N_C); //!< \f$C_F\f$
  constexpr double t_f = 0.5; //!< \f$t_f\f$
  constexpr double n_f = 5.;    //!< number light flavours
  constexpr double beta0 = 11./3.*C_A - 4./3.*t_f*n_f;  //!< \f$\beta_0\f$
//@}
/// @name QFT parameters
//@{
  constexpr double vev = 246.2196508; //!< Higgs vacuum expectation value in GeV
//@}
/// @name Generation Parameters
//@{
  constexpr double CLAMBDA = 0.2;   //!< Scale for virtual correction, \f$\lambda\f$ cf. eq. (20) in \cite Andersen:2011hs
  constexpr double CMINPT = CLAMBDA;  //!< minimal \f$p_t\f$ of all partons
//@}
}
