/** \file
 *  \brief Declaration of the trivial (empty) analysis
 *
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */

#pragma once

#include <memory>

#include "HEJ/Analysis.hh"

//! YAML Namespace
namespace YAML{
  class Node;
}

namespace HEJ{
  /** An analysis that does nothing
   *
   *  This analysis is used by default if no user analysis is specified.
   *  The member functions don't do anything and events passed to the
   *  analysis are simply ignored.
   */
  struct EmptyAnalysis: Analysis{
    static std::unique_ptr<Analysis> create(YAML::Node const & parameters);

    //! Fill event into analysis (e.g. to histograms)
    /**
     *  This function does nothing
     */
    virtual void fill(Event const &, Event const &) override;
    //! Whether a resummation event passes all cuts
    /**
     *  There are no cuts, so all events pass
     */
    virtual bool pass_cuts(Event const &, Event const &) override;
    //! Finalise analysis
    /**
     * This function does nothing
     */
    virtual void finalise() override;

    virtual ~EmptyAnalysis() override = default;
  };
}
