/** \file
 * \brief The Mixmax random number generator
 *
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */
#pragma once

#include <CLHEP/Random/Randomize.h>
#include <CLHEP/Random/MixMaxRng.h>

#include "HEJ/RNG.hh"

namespace HEJ {

  //! MIXMAX random number generator
  /**
   *  For details on MIXMAX, see \cite Savvidy:2014ana
   */
  class Mixmax : public DefaultRNG {
  public:
    Mixmax() = default;
    Mixmax(long seed): ran_{seed} {};

    //! Generate pseudorandom number between 0 and 1
    double flat() override {
      return ran_.flat();
    };

  private:
    CLHEP::MixMaxRng ran_;
  };

}
