/** \file
 *  \brief Contains the get_analysis function
 *
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */

#pragma once

#include <memory>

#include "HEJ/Analysis.hh"

namespace YAML{
  class Node;
}

namespace HEJ{
  //!  Load an analysis
  /**
   *  @param parameters    Analysis parameters
   *  @returns             A pointer to an Analysis instance
   *
   *  If parameters["plugin"] exists, an analysis (deriving from the
   *  \ref Analysis class) will be loaded from the library parameters["plugin"].
   *  Otherwise, if parameters["rivet"] exists, the corresponding RivetAnalysis
   *  will be loaded. If none of these parameters are specified, a pointer to
   *  the default EmptyAnalysis is returned.
   */
  std::unique_ptr<Analysis> get_analysis(YAML::Node const & parameters);
}
