/** \file
 *  \brief Defines the optional type
 *
 *  The C++14 standard introduces the std::optional type.
 *  If C++14 is not available, we use the optional type from boost instead.
 *
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */
#pragma once

#if __cplusplus <= 201402L
#include <boost/optional.hpp>
#else
#include <optional>
#endif

namespace HEJ{

#if __cplusplus <= 201402L
  template<typename T>
  using optional = boost::optional<T>;
#else
  template<typename T>
  using optional = std::optional<T>;
#endif
}
