/**
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */
#include "HEJ/PDG_codes.hh"

#include <map>

#include "HEJ/exceptions.hh"

namespace HEJ{
  ParticleID to_ParticleID(std::string const & name){
    using namespace HEJ::pid;
    static const std::map<std::string, ParticleID> known = {
      {"d", d}, {"down", down}, {"1",static_cast<ParticleID>(1)},
      {"u", u}, {"up", up}, {"2",static_cast<ParticleID>(2)},
      {"s", s}, {"strange", strange}, {"3",static_cast<ParticleID>(3)},
      {"c", c}, {"charm", charm}, {"4",static_cast<ParticleID>(4)},
      {"b", b}, {"bottom", bottom}, {"5",static_cast<ParticleID>(5)},
      {"t", t}, {"top", top}, {"6",static_cast<ParticleID>(6)},
      {"e", e}, {"electron", electron}, {"e-", e}, {"11",static_cast<ParticleID>(11)},
      {"nu_e", nu_e}, {"electron_neutrino", electron_neutrino}, {"12",static_cast<ParticleID>(12)},
      {"mu", mu}, {"muon", muon}, {"mu-", mu}, {"13",static_cast<ParticleID>(13)},
      {"nu_mu", nu_mu}, {"muon_neutrino", muon_neutrino}, {"14",static_cast<ParticleID>(14)},
      {"tau", tau}, {"tau-", tau}, {"15",static_cast<ParticleID>(15)},
      {"nu_tau", nu_tau}, {"tau_neutrino", tau_neutrino}, {"16",static_cast<ParticleID>(16)},
      {"d_bar", d_bar}, {"-1",static_cast<ParticleID>(-1)},
      {"u_bar", u_bar}, {"-2",static_cast<ParticleID>(-2)},
      {"s_bar", s_bar}, {"-3",static_cast<ParticleID>(-3)},
      {"c_bar", c_bar}, {"-4",static_cast<ParticleID>(-4)},
      {"b_bar", b_bar}, {"-5",static_cast<ParticleID>(-5)},
      {"t_bar", t_bar}, {"-6",static_cast<ParticleID>(-6)},
      {"e_bar", e_bar}, {"positron", positron}, {"e+", e_bar}, {"-11",static_cast<ParticleID>(-11)},
      {"nu_e_bar", nu_e_bar}, {"-12",static_cast<ParticleID>(-12)},
      {"mu_bar", mu_bar}, {"mu+", mu_bar}, {"-13",static_cast<ParticleID>(-13)},
      {"nu_mu_bar", nu_mu_bar}, {"-14",static_cast<ParticleID>(-14)},
      {"tau_bar", tau_bar}, {"tau+", tau_bar}, {"-15",static_cast<ParticleID>(-15)},
      {"nu_tau_bar", nu_tau_bar}, {"-16",static_cast<ParticleID>(-16)},
      {"gluon", gluon}, {"g", g}, {"21",static_cast<ParticleID>(21)},
      {"photon", photon}, {"gamma", gamma}, {"22",static_cast<ParticleID>(22)},
      {"Z", Z}, {"23",static_cast<ParticleID>(23)},
      {"Wp", Wp}, {"W+", Wp}, {"24",static_cast<ParticleID>(24)},
      {"Wm", Wm}, {"W-", Wm}, {"-24",static_cast<ParticleID>(-24)},
      {"h", h}, {"H", h}, {"Higgs", Higgs}, {"higgs", higgs}, {"25",static_cast<ParticleID>(25)},
      {"p", p}, {"proton", proton}, {"p_bar", p_bar}, {"2212",static_cast<ParticleID>(2212)}
    };
    const auto res = known.find(name);
    if(res == known.end()){
      throw std::invalid_argument("Unknown particle " + name);
    }
    return res->second;
  }
}
