/**
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */
#include "HEJ/get_analysis.hh"

#include <dlfcn.h>
#include <string>

#include "yaml-cpp/yaml.h"

#include "HEJ/EmptyAnalysis.hh"
#include "HEJ/RivetAnalysis.hh"

namespace HEJ{

  std::unique_ptr<Analysis> get_analysis(YAML::Node const & parameters){
    if(!parameters["plugin"]){
      if(parameters["rivet"])
        return RivetAnalysis::create(parameters);
      return EmptyAnalysis::create(parameters);
    }

    using AnalysisMaker = std::unique_ptr<Analysis> (*)(YAML::Node);
    const auto plugin_name = parameters["plugin"].as<std::string>();
    auto handle = dlopen(plugin_name.c_str(), RTLD_NOW);
    char * error = dlerror();
    if(error != nullptr) throw std::runtime_error(error);

    void * sym = dlsym(handle, "make_analysis");
    error = dlerror();
    if(error != nullptr) throw std::runtime_error(error);
    auto make_analysis = reinterpret_cast<AnalysisMaker>(sym);

    return make_analysis(parameters);
  }
}
