/**
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */
#include "HEJ/make_writer.hh"

#include "HEJ/exceptions.hh"
#include "HEJ/HepMCWriter.hh"
#include "HEJ/LesHouchesWriter.hh"

namespace HEJ{
  std::unique_ptr<EventWriter> make_format_writer(
      FileFormat format, std::string const & outfile,
      LHEF::HEPRUP const & heprup
  ){
    switch(format){
    case Les_Houches:
      return std::unique_ptr<EventWriter>{
        new LesHouchesWriter{outfile, heprup}
      };
    case HepMC:
      return std::unique_ptr<EventWriter>{
        new HepMCWriter{outfile, heprup}
      };
    default:
      throw std::logic_error("unhandled file format");
    }
  }

}
