/**
 *  \authors   Jeppe Andersen, Tuomas Hapola, Marian Heil, Andreas Maier, Jennifer Smillie
 *  \date      2019
 *  \copyright GPLv2 or later
 */
#include "HEJ/stream.hh"

#include <boost/iostreams/filter/gzip.hpp>

namespace HEJ{

  namespace{
    bool is_gzip(std::ifstream & file){
      static constexpr char magic_bytes[] = {'\x1f', '\x8b'};
      if(file.peek() != magic_bytes[0]) return false;
      file.get();
      const char second = file.peek();
      file.unget();
      return second == magic_bytes[1];
    }
  }

  istream::istream(std::string const & filename):
    file_{filename, std::ios_base::in | std::ios_base::binary},
    stream_{new boost_istream()}
  {
    if(is_gzip(file_)){
      stream_->push(boost::iostreams::gzip_decompressor{});
    }
    stream_->push(file_);
  }
}
